@@ -25,7 +25,7 @@ sub new {
 
 	my @packages = @{$dh{DOPACKAGES}};
 	$this->{package} = shift @packages;
-	$this->{doc_package} = (grep /-doc$/, @packages)[0] && (get_buildoption("nodoc") != 1);
+	$this->{doc_package} = (grep /-doc$/, @packages)[0] unless get_buildoption("nodoc");
 	my $classconf = '/etc/maven/m2-debian.conf';
 
 	my @classpath = ('/usr/share/maven/boot/plexus-classworlds-2.x.jar');
